<?php
session_start();
include 'config.php'; 
$error = '';

if ($_SERVER["REQUEST_METHOD"] == "POST") {
    $user_phone = trim($_POST['user_phone']);
    $user_password = trim($_POST['user_password']);

    if (empty($user_phone) || empty($user_password)) {
        $error = "Fill All Required Fields.";
    } else {
        $stmt = $conn->prepare("SELECT user_id, user_name, user_phone, user_email FROM login_users WHERE user_phone = ? AND user_password = ?");
        $stmt->bind_param("ss", $user_phone, $user_password);
        $stmt->execute();
        $result = $stmt->get_result();

        if ($result->num_rows == 1) {
            // Fetch user details
            $user = $result->fetch_assoc();

            // Store user details in session
            $_SESSION['user_id'] = $user['user_id'];
            $_SESSION['user_name'] = $user['user_name'];
            $_SESSION['user_phone'] = $user['user_phone'];
            $_SESSION['user_email'] = $user['user_email'];

            // Redirect to homepage
            echo "<script>
                    localStorage.setItem('successMessage', 'Logged in successfully');
                    window.location.href = 'categories.php';
                  </script>";
            exit();
        } else {
            $error = "Invalid phone number or password. Please try again.";
        }

        $stmt->close();
    }
    $conn->close();
}
?>


<!DOCTYPE html>
<html lang="en">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Login Page</title>
    <script src="https://cdn.tailwindcss.com"></script>
    <link href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0/css/all.min.css" rel="stylesheet">
    
    <style>
  .required {
    color: red;
  }
</style>

</head>

<body>
    
    <div class="flex items-center justify-center h-screen bg-gray-100">
        <div class="flex flex-wrap md:flex-nowrap w-full max-w-5xl bg-white rounded-lg overflow-hidden">
            <!-- Image Section -->
            <div class="hidden md:block md:w-1/2">
                <img src="login-image.svg" alt="Login Image" class="w-full h-full object-cover">
            </div>

            <!-- Content Section -->
            <div class="w-full md:w-1/2 p-8">
                <div class="justify-center items-center my-16">
                    <h2 class="text-3xl font-semibold text-gray-800 mb-6 text-center">Welcome Back!</h2>
                    <p class="text-gray-600 mb-8 text-center">Please login to your account</p>

                    <form method="POST" class="space-y-6" onsubmit="return validateForm()">
                        <!-- Phone Number Field -->
                        <div class="relative">
                            <input type="text" id="user_phone" name="user_phone" placeholder="Enter Your Mobile No"
                                class="w-full px-4 py-2 pl-10 border <?php echo isset($phoneError) && $phoneError ? 'border-red-500' : 'border-gray-300'; ?> rounded-lg focus:outline-none focus:ring-2 focus:ring-[#683ba9]">
                            <span class="absolute inset-y-0 left-3 flex items-center text-gray-400">
                                <i class="fas fa-phone"></i>
                            </span>
                        </div>

                        <!-- Password Field -->
                        <div class="relative">
                            <input type="password" id="user_password" name="user_password" placeholder="Enter Your Password"
                                class="w-full px-4 py-2 pl-10 border <?php echo isset($passwordError) && $passwordError ? 'border-red-500' : 'border-gray-300'; ?> rounded-lg focus:outline-none focus:ring-2 focus:ring-[#683ba9]">
                            <span class="absolute inset-y-0 left-3 flex items-center text-gray-400">
                                <i class="fas fa-lock"></i>
                            </span>
                            <button type="button" class="absolute inset-y-0 right-3 flex items-center text-gray-400"
                                onclick="togglePasswordVisibility()">
                                <i id="eye-icon" class="fas fa-eye hidden"></i>
                                <i id="eye-slash-icon" class="fas fa-eye-slash"></i>
                            </button>
                        </div>

                        <!-- Error Message -->
                        <div id="error-message" class="flex mt-4 text-xs text-red-500 sm:text-sm">
                        <?php if (!empty($error)): ?>
                            <div class="flex justify-center mt-4 text-sm text-red-500">
                                <span><?php echo $error; ?></span>
                            </div>
                        <?php endif; ?>
                        </div>

                        <!-- Submit Button -->
                        <button type="submit"
                            class="w-full bg-[#683ba9] text-white py-2 px-4 rounded-lg hover:bg-[#5a3091] transition">Login</button>
                    </form>

                </div>
            </div>
        </div>
    </div>
    <script>
    window.onload = function () {
        document.getElementById("user_phone").value = "";
        document.getElementById("user_password").value = "";
    };

    function validateForm() {
    let phone = document.getElementById("user_phone");
    let password = document.getElementById("user_password");
    let isValid = true;

    // Reset previous error styles
    phone.classList.remove("border-red-500");
    password.classList.remove("border-red-500");

    if (phone.value.trim() === "") {
        phone.classList.add("border-red-500");
        isValid = false;
    }

    if (password.value.trim() === "") {
        password.classList.add("border-red-500");
        isValid = false;
    }

    if (!isValid) {
        document.getElementById("error-message").innerText = "Fill All Required Fields.";
        return false;
    }

    return true;
}


    function togglePasswordVisibility() {
        const passwordInput = document.getElementById("user_password");
        const eyeIcon = document.getElementById("eye-icon");
        const eyeSlashIcon = document.getElementById("eye-slash-icon");

        if (passwordInput.type === "password") {
            passwordInput.type = "text";
            eyeIcon.classList.remove("hidden");
            eyeSlashIcon.classList.add("hidden");
        } else {
            passwordInput.type = "password";
            eyeIcon.classList.add("hidden");
            eyeSlashIcon.classList.remove("hidden");
        }
    }
</script>

</body>

</html>